# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/assetise/asset_type/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Assetise\\AssetType\\": "packages/assetise/asset_type/src",
            "Assetise\\AssetType\\Seeders\\": "packages/assetise/asset_type/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Assetise\AssetType\Providers\AssetTypeServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'AssetType'  => Assetise\AssetType\Facades\AssetType::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Assetise\\AssetType\\Seeders\\AssetTypeTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Assetise\AssetType\Providers\AssetTypeServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Assetise\AssetType\Providers\AssetTypeServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Assetise\AssetType\Providers\AssetTypeServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/asset_type/{modulename}

**User**

    http://path-to-route-folder/user/asset_type/{modulename}

**Public**

    http://path-to-route-folder/asset_types


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/asset_type/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/asset_type/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/asset_type/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/asset_type/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/asset_type/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/asset_type/{modulename}/{slug}
    METHOD: GET