<?php

namespace Assetise\AssetType\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Assetise\AssetType\Http\Resources\AssetTypeResource;
use Assetise\AssetType\Http\Resources\AssetTypesCollection;
use Assetise\AssetType\Scopes\AssetTypePublicScope;
use Assetise\AssetType\Models\AssetType;

class AssetTypePublicController extends BaseController
{

    /**
     * Show asset_type's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = AssetType::pushScope(new RequestScope())
            ->pushScope(new AssetTypePublicScope())
            ->select('asset_types.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new AssetTypesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('asset_type::asset_type.names'))
            ->view('asset_type::public.asset_type.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show asset_type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = AssetType::findBySlug($slug);
        $data = new AssetTypeResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('asset_type::asset_type.name'))
            ->view('asset_type::public.asset_type.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
